@@ -19,11 +19,14 @@
 #  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 # ##############################################################################
 
+__version__ = "10.0.32"
+__install_type__ = "pip"
 
 import argparse
 import atexit
 import gettext
 import os
+import pathlib
 import site
 import subprocess
 import sys
@@ -32,15 +35,18 @@ import time
 import traceback
 from signal import SIGTERM
 
+import pkg_resources
+
 app = None
 
 MAIN_DIR = os.path.abspath(os.path.realpath(os.path.expanduser(os.path.dirname(os.path.dirname(__file__)))))
 PROG_DIR = os.path.abspath(os.path.realpath(os.path.expanduser(os.path.dirname(__file__))))
 LOCALE_DIR = os.path.join(PROG_DIR, 'locale')
 LIBS_DIR = os.path.join(PROG_DIR, 'libs')
-VERSION_FILE = os.path.join(PROG_DIR, 'version.txt')
 CHANGELOG_FILE = os.path.join(MAIN_DIR, 'CHANGELOG.md')
 REQS_FILE = os.path.join(MAIN_DIR, 'requirements.txt')
+CHECKSUM_FILE = os.path.join(PROG_DIR, 'checksums.md5')
+AUTO_PROCESS_TV_CFG_FILE = os.path.join(*[PROG_DIR, 'autoProcessTV', 'autoProcessTV.cfg'])
 
 
 class Daemon(object):
@@ -157,49 +163,72 @@ class Daemon(object):
                 sys.exit(1)
 
 
-def isElevatedUser():
-    try:
-        return os.getuid() == 0
-    except AttributeError:
-        import ctypes
-        return ctypes.windll.shell32.IsUserAnAdmin() != 0
-
-
-def isVirtualEnv():
-    return hasattr(sys, 'real_prefix')
-
-
-def check_requirements():
-    # sickrage requires python 3.5+
-    if sys.version_info < (3, 5, 0):
-        sys.exit("Sorry, SiCKRAGE requires Python 3.5+")
-
-    try:
-        import OpenSSL
-
-        v = OpenSSL.__version__
-        v_needed = '0.15'
-
-        if not v >= v_needed:
-            print('OpenSSL installed but {} is needed while {} is installed. '
-                  'Run `pip install -U pyopenssl`'.format(v_needed, v))
-    except ImportError:
-        print('OpenSSL not available, please install for better requests validation: '
-              '`https://pyopenssl.readthedocs.org/en/latest/install.html`')
-
-
 def version():
-    # Get the version number
-    with open(VERSION_FILE) as f:
-        return f.read()
+    # Return the version number
+    return __version__
+
+
+def install_type():
+    # Return the install type
+    if not __install_type__ and os.path.isdir(os.path.join(MAIN_DIR, '.git')):
+        return 'git'
+    else:
+        return __install_type__ or 'source'
 
 
 def changelog():
-    # Get the version number
+    # Return contents of CHANGELOG.md
     with open(CHANGELOG_FILE) as f:
         return f.read()
 
 
+def check_requirements():
+    if os.path.exists(REQS_FILE):
+        with open(REQS_FILE) as f:
+            for line in f.readlines():
+                try:
+                    req_name, req_version = line.strip().split('==')
+                    if not pkg_resources.get_distribution(req_name).version == req_version:
+                        print('Updating requirement {} to {}'.format(req_name, req_version))
+                        subprocess.check_call([sys.executable, "-m", "pip", "install", "--no-deps", "--no-cache-dir", line.strip()])
+                except pkg_resources.DistributionNotFound:
+                    print('Installing requirement {}'.format(line.strip()))
+                    subprocess.check_call([sys.executable, "-m", "pip", "install", "--no-deps", "--no-cache-dir", line.strip()])
+                except ValueError:
+                    continue
+
+
+def verify_checksums(remove_unverified=False):
+    valid_files = []
+    exempt_files = [pathlib.Path(__file__), pathlib.Path(CHECKSUM_FILE), pathlib.Path(AUTO_PROCESS_TV_CFG_FILE)]
+
+    if not os.path.exists(CHECKSUM_FILE):
+        return
+
+    with open(CHECKSUM_FILE, "rb") as fp:
+        for line in fp.readlines():
+            file, checksum = line.decode().strip().split(' = ')
+            full_filename = pathlib.Path(MAIN_DIR).joinpath(file)
+            valid_files.append(full_filename)
+
+    for root, dirs, files in os.walk(PROG_DIR):
+        for file in files:
+            full_filename = pathlib.Path(root).joinpath(file)
+
+            if full_filename in exempt_files or full_filename.suffix == '.pyc':
+                continue
+
+            if full_filename not in valid_files and PROG_DIR in str(full_filename):
+                try:
+                    if remove_unverified:
+                        print('Found unverified file {}, removed!'.format(full_filename))
+                        full_filename.unlink()
+                    else:
+                        print('Found unverified file {}, you should delete this file manually!'.format(full_filename))
+                except OSError:
+                    print('Unable to delete unverified filename {} during checksum verification, you should delete this file manually!'.format(full_filename))
+
+
 def main():
     global app
 
@@ -218,83 +247,94 @@ def main():
     # set system default language
     gettext.install('messages', LOCALE_DIR, codeset='UTF-8', names=["ngettext"])
 
+    # sickrage startup options
+    parser = argparse.ArgumentParser(prog='sickrage')
+    parser.add_argument('-v', '--version',
+                        action='version',
+                        version=version())
+    parser.add_argument('-d', '--daemon',
+                        action='store_true',
+                        help='Run as a daemon (*NIX ONLY)')
+    parser.add_argument('-q', '--quiet',
+                        action='store_true',
+                        help='Disables logging to CONSOLE')
+    parser.add_argument('-p', '--port',
+                        default=0,
+                        type=int,
+                        help='Override default/configured port to listen on')
+    parser.add_argument('-H', '--host',
+                        default='',
+                        help='Override default/configured host to listen on')
+    parser.add_argument('--dev',
+                        action='store_true',
+                        help='Enable developer mode')
+    parser.add_argument('--debug',
+                        action='store_true',
+                        help='Enable debugging')
+    parser.add_argument('--datadir',
+                        default=os.path.abspath(os.path.join(os.path.expanduser("~"), '.sickrage')),
+                        help='Overrides data folder for database, config, cache and logs (specify full path)')
+    parser.add_argument('--config',
+                        default='config.ini',
+                        help='Overrides config filename (specify full path and filename if outside datadir path)')
+    parser.add_argument('--pidfile',
+                        default='sickrage.pid',
+                        help='Creates a PID file (specify full path and filename if outside datadir path)')
+    parser.add_argument('--no_clean',
+                        action='store_true',
+                        help='Suppress cleanup of files not present in checksum.md5')
+    parser.add_argument('--nolaunch',
+                        action='store_true',
+                        help='Suppress launching web browser on startup')
+    parser.add_argument('--disable_updates',
+                        action='store_true',
+                        help='Disable application updates')
+    parser.add_argument('--web_root',
+                        default='',
+                        type=str,
+                        help='Overrides URL web root')
+    parser.add_argument('--db_type',
+                        default='sqlite',
+                        help='Database type: sqlite or mysql')
+    parser.add_argument('--db_prefix',
+                        default='sickrage',
+                        help='Database prefix you want prepended to database table names')
+    parser.add_argument('--db_host',
+                        default='localhost',
+                        help='Database hostname (not used for sqlite)')
+    parser.add_argument('--db_port',
+                        default='3306',
+                        help='Database port number (not used for sqlite)')
+    parser.add_argument('--db_username',
+                        default='sickrage',
+                        help='Database username (not used for sqlite)')
+    parser.add_argument('--db_password',
+                        default='sickrage',
+                        help='Database password (not used for sqlite)')
+
+    # Parse startup args
+    args = parser.parse_args()
+
+    # sickrage requires python 3.6+
+    if sys.version_info < (3, 6, 0):
+        sys.exit("Sorry, SiCKRAGE requires Python 3.6+")
+
+    # check lib requirements
+    if install_type() not in ['windows', 'synology', 'docker', 'qnap', 'readynas', 'pip']:
+        check_requirements()
+
+    # verify file checksums, remove unverified files
+    verify_checksums(remove_unverified=not args.no_clean)
+
     try:
-        try:
-            from sickrage.core import Core
-        except ImportError:
-            print('Attempting to install SiCKRAGE missing requirements using pip')
-            subprocess.check_call([sys.executable, "-m", "pip", "install", "--no-cache-dir", "-r", REQS_FILE])
-            from sickrage.core import Core
+        from sickrage.core import Core
 
         # main app instance
         app = Core()
 
-        # sickrage startup options
-        parser = argparse.ArgumentParser(prog='sickrage')
-        parser.add_argument('-v', '--version',
-                            action='version',
-                            version='%(prog)s {}'.format(version()))
-        parser.add_argument('-d', '--daemon',
-                            action='store_true',
-                            help='Run as a daemon (*NIX ONLY)')
-        parser.add_argument('-q', '--quiet',
-                            action='store_true',
-                            help='Disables logging to CONSOLE')
-        parser.add_argument('-p', '--port',
-                            default=0,
-                            type=int,
-                            help='Override default/configured port to listen on')
-        parser.add_argument('-H', '--host',
-                            default='',
-                            help='Override default/configured host to listen on')
-        parser.add_argument('--dev',
-                            action='store_true',
-                            help='Enable developer mode')
-        parser.add_argument('--debug',
-                            action='store_true',
-                            help='Enable debugging')
-        parser.add_argument('--datadir',
-                            default=os.path.abspath(os.path.join(os.path.expanduser("~"), '.sickrage')),
-                            help='Overrides data folder for database, config, cache and logs (specify full path)')
-        parser.add_argument('--config',
-                            default='config.ini',
-                            help='Overrides config filename (specify full path and filename if outside datadir path)')
-        parser.add_argument('--pidfile',
-                            default='sickrage.pid',
-                            help='Creates a PID file (specify full path and filename if outside datadir path)')
-        parser.add_argument('--nolaunch',
-                            action='store_true',
-                            help='Suppress launching web browser on startup')
-        parser.add_argument('--disable_updates',
-                            action='store_true',
-                            help='Disable application updates')
-        parser.add_argument('--web_root',
-                            default='',
-                            help='Overrides URL web root')
-        parser.add_argument('--db_type',
-                            default='sqlite',
-                            help='Database type: sqlite or mysql')
-        parser.add_argument('--db_prefix',
-                            default='sickrage',
-                            help='Database prefix you want prepended to database table names')
-        parser.add_argument('--db_host',
-                            default='localhost',
-                            help='Database hostname (not used for sqlite)')
-        parser.add_argument('--db_port',
-                            default='3306',
-                            help='Database port number (not used for sqlite)')
-        parser.add_argument('--db_username',
-                            default='sickrage',
-                            help='Database username (not used for sqlite)')
-        parser.add_argument('--db_password',
-                            default='sickrage',
-                            help='Database password (not used for sqlite)')
-
-        # Parse startup args
-        args = parser.parse_args()
         app.quiet = args.quiet
-        app.web_port = int(args.port)
         app.web_host = args.host
+        app.web_port = int(args.port)
         app.web_root = args.web_root.lstrip('/').rstrip('/')
         app.no_launch = args.nolaunch
         app.disable_updates = args.disable_updates
@@ -318,9 +358,6 @@ def main():
         if not os.path.isabs(pid_file):
             pid_file = os.path.join(app.data_dir, pid_file)
 
-        # check lib requirements
-        check_requirements()
-
         # add sickrage module to python system path
         if not (PROG_DIR in sys.path):
             sys.path, remainder = sys.path[:1], sys.path[1:]
@@ -362,7 +399,14 @@ def main():
     except (SystemExit, KeyboardInterrupt):
         if app:
             app.shutdown()
-    except Exception:
+    except Exception as e:
+        # attempt to send exception to sentry
+        try:
+            import sentry_sdk
+            sentry_sdk.capture_exception(e)
+        except ImportError:
+            pass
+
         traceback.print_exc()
 
 
