@@ -1,30 +1,31 @@
-#!/usr/bin/env python2.7
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+#!/usr/bin/env python3
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import print_function, unicode_literals
 
-import ConfigParser
-import io
 import logging
 import os
 import sys
 import time
+from configparser import ConfigParser
 
 import requests
 
@@ -32,10 +33,10 @@ sickragePath = os.path.split(os.path.split(sys.argv[0])[0])[0]
 sys.path.append(sickragePath)
 configFilename = os.path.join(sickragePath, "config.ini")
 
-config = ConfigParser.ConfigParser()
+config = ConfigParser()
 
 try:
-    with io.open(configFilename, "r") as fp:
+    with open(configFilename, "r") as fp:
         config.readfp(fp)
 except IOError as e:
     print("Could not find/read SiCKRAGE config.ini: " + str(e))
@@ -83,7 +84,7 @@ def transmission():
     dirName = os.getenv('TR_TORRENT_DIR')
     nzbName = os.getenv('TR_TORRENT_NAME')
 
-    return (dirName, nzbName)
+    return dirName, nzbName
 
 
 def deluge():
@@ -96,11 +97,11 @@ def deluge():
     dirName = sys.argv[3]
     nzbName = sys.argv[2]
 
-    return (dirName, nzbName)
+    return dirName, nzbName
 
 
 def blackhole():
-    if None != os.getenv('TR_TORRENT_DIR'):
+    if os.getenv('TR_TORRENT_DIR') is not None:
         scriptlogger.debug('Processing script triggered by Transmission')
         print("Processing script triggered by Transmission")
         scriptlogger.debug('TR_TORRENT_DIR: ' + os.getenv('TR_TORRENT_DIR'))
@@ -117,15 +118,16 @@ def blackhole():
         dirName = sys.argv[1]
         nzbName = sys.argv[2]
 
-    return (dirName, nzbName)
+    return dirName, nzbName
+
 
 def main():
     scriptlogger.info('Starting external PostProcess script ' + __file__)
 
     host = config.get("General", "web_host")
     port = config.get("General", "web_port")
-    username = config.get("General", "web_username")
-    password = config.get("General", "web_password")
+    api_key = config.get("General", "api_key")
+
     try:
         ssl = int(config.get("General", "enable_https"))
     except (ConfigParser.NoOptionError, ValueError):
@@ -169,10 +171,14 @@ def main():
     if nzbName and os.path.isdir(os.path.join(dirName, nzbName)):
         dirName = os.path.join(dirName, nzbName)
 
-    params = {'quiet': 1, 'dir': dirName}
+    params = {
+        'cmd': 'postprocess',
+        'return_data': 0,
+        'path': dirName
+    }
 
-    if nzbName is not None:
-        params['nzbName'] = nzbName
+    # if nzbName is not None:
+    #     params['nzbName'] = nzbName
 
     if ssl:
         protocol = "https://"
@@ -182,25 +188,22 @@ def main():
     if host == '0.0.0.0':
         host = 'localhost'
 
-    url = protocol + host + ":" + port + web_root + "/home/postprocess/processEpisode"
-    login_url = protocol + host + ':' + port + web_root + '/login'
+    url = "{}{}:{}{}api/{}/".format(protocol, host, port, web_root, api_key)
 
     scriptlogger.debug("Opening URL: " + url + ' with params=' + str(params))
     print("Opening URL: " + url + ' with params=' + str(params))
 
     try:
-        sess = requests.Session()
-        sess.post(login_url, data={'username': username, 'password': password}, stream=True, verify=False)
-        response = sess.get(url, auth=(username, password), params=params, verify=False,  allow_redirects=False)
+        response = requests.get(url, params=params, verify=False, allow_redirects=False)
     except Exception as err:
         scriptlogger.error(': Unknown exception raised when opening url: ' + str(err))
         time.sleep(3)
         sys.exit('Unknown exception raised when opening url: ' + str(err))
 
     if response.status_code == 401:
-        scriptlogger.error('Invalid SiCKRAGE Username or Password, check your config')
+        scriptlogger.error('Invalid SiCKRAGE API key, check your config')
         time.sleep(3)
-        sys.exit('Invalid SiCKRAGE Username or Password, check your config')
+        sys.exit('Invalid SiCKRAGE API key, check your config')
 
     if response.ok:
         scriptlogger.info('Script ' + __file__ + ' Succesfull')
