@@ -21,7 +21,7 @@
 
 
 import datetime
-import functools
+import threading
 import time
 
 import feedparser
@@ -29,10 +29,11 @@ from sqlalchemy import orm
 from sqlalchemy.exc import IntegrityError
 
 import sickrage
-from sickrage.core.common import Quality
+from sickrage.core.common import Quality, Qualities
 from sickrage.core.databases.cache import CacheDB
+from sickrage.core.enums import SeriesProviderID
 from sickrage.core.exceptions import AuthException
-from sickrage.core.helpers import show_names, validate_url, is_ip_private, try_int
+from sickrage.core.helpers import show_names, try_int
 from sickrage.core.nameparser import InvalidNameException, NameParser, InvalidShowException
 from sickrage.core.tv.show.helpers import find_show
 from sickrage.core.websession import WebSession
@@ -40,6 +41,7 @@ from sickrage.core.websession import WebSession
 
 class TVCache(object):
     def __init__(self, provider, **kwargs):
+        self.lock = threading.Lock()
         self.provider = provider
         self.providerID = self.provider.id
         self.min_time = kwargs.pop('min_time', 10)
@@ -85,12 +87,13 @@ class TVCache(object):
                 self.last_update = datetime.datetime.today()
 
                 [self._parseItem(item) for item in data['entries']]
+
+                sickrage.app.log.debug("Updated RSS cache")
             except AuthException as e:
                 sickrage.app.log.warning("Authentication error: {}".format(e))
                 return False
             except Exception as e:
-                sickrage.app.log.debug(
-                    "Error while searching {}, skipping: {}".format(self.provider.name, repr(e)))
+                sickrage.app.log.debug("Error while searching {}, skipping: {}".format(self.provider.name, repr(e)))
                 return False
 
         return True
@@ -98,7 +101,7 @@ class TVCache(object):
     def get_rss_feed(self, url, params=None):
         try:
             if self.provider.login():
-                resp = WebSession().get(url, params=params)
+                resp = WebSession().get(url, timeout=30, params=params)
                 if resp:
                     return feedparser.parse(resp.text)
         except Exception as e:
@@ -143,16 +146,17 @@ class TVCache(object):
     def last_update(self, toDate):
         session = sickrage.app.cache_db.session()
 
-        try:
-            dbData = session.query(CacheDB.LastUpdate).filter_by(provider=self.providerID).one()
-            dbData.time = int(time.mktime(toDate.timetuple()))
-        except orm.exc.NoResultFound:
-            session.add(CacheDB.LastUpdate(**{
-                'provider': self.providerID,
-                'time': int(time.mktime(toDate.timetuple()))
-            }))
-        finally:
-            session.commit()
+        with self.lock:
+            try:
+                dbData = session.query(CacheDB.LastUpdate).filter_by(provider=self.providerID).one()
+                dbData.time = int(time.mktime(toDate.timetuple()))
+            except orm.exc.NoResultFound:
+                session.add(CacheDB.LastUpdate(**{
+                    'provider': self.providerID,
+                    'time': int(time.mktime(toDate.timetuple()))
+                }))
+            finally:
+                session.commit()
 
     @property
     def last_search(self):
@@ -172,16 +176,17 @@ class TVCache(object):
     def last_search(self, toDate):
         session = sickrage.app.cache_db.session()
 
-        try:
-            dbData = session.query(CacheDB.LastSearch).filter_by(provider=self.providerID).one()
-            dbData.time = int(time.mktime(toDate.timetuple()))
-        except orm.exc.NoResultFound:
-            session.add(CacheDB.LastSearch(**{
-                'provider': self.providerID,
-                'time': int(time.mktime(toDate.timetuple()))
-            }))
-        finally:
-            session.commit()
+        with self.lock:
+            try:
+                dbData = session.query(CacheDB.LastSearch).filter_by(provider=self.providerID).one()
+                dbData.time = int(time.mktime(toDate.timetuple()))
+            except orm.exc.NoResultFound:
+                session.add(CacheDB.LastSearch(**{
+                    'provider': self.providerID,
+                    'time': int(time.mktime(toDate.timetuple()))
+                }))
+            finally:
+                session.commit()
 
     def should_update(self):
         # if we've updated recently then skip the update
@@ -202,23 +207,16 @@ class TVCache(object):
         if session.query(CacheDB.Provider).filter_by(url=url).count():
             return
 
-        # ignore invalid and private IP address urls
-        if not validate_url(url):
-            if not url.startswith('magnet'):
-                return
-        elif is_ip_private(url.split(r'//')[-1].split(r'/')[0]):
-            return
-
         try:
             # parse release name
             parse_result = NameParser(validate_show=True).parse(name)
-            if parse_result.series_name and parse_result.quality != Quality.UNKNOWN:
+            if parse_result.series_name and parse_result.quality != Qualities.UNKNOWN:
                 season = parse_result.season_number if parse_result.season_number else 1
                 episodes = parse_result.episode_numbers
 
                 if season and episodes:
                     # store episodes as a seperated string
-                    episodeText = "|" + "|".join(map(str, episodes)) + "|"
+                    episode_text = "|" + "|".join(map(str, episodes)) + "|"
 
                     # get quality of release
                     quality = parse_result.quality
@@ -233,8 +231,9 @@ class TVCache(object):
                         'provider': self.providerID,
                         'name': name,
                         'season': season,
-                        'episodes': episodeText,
-                        'series_id': parse_result.indexer_id,
+                        'episodes': episode_text,
+                        'series_id': parse_result.series_id,
+                        'series_provider_id': parse_result.series_provider_id.name,
                         'url': url,
                         'time': int(time.mktime(datetime.datetime.today().timetuple())),
                         'quality': quality,
@@ -254,54 +253,55 @@ class TVCache(object):
                         pass
 
                     # add to external provider cache database
-                    if sickrage.app.config.enable_api_providers_cache and not self.provider.private:
-                        try:
-                            sickrage.app.io_loop.run_in_executor(None, functools.partial(sickrage.app.api.provider_cache.add, data=dbData))
-                        except Exception as e:
-                            pass
+                    if sickrage.app.config.general.enable_sickrage_api:
+                        from sickrage.search_providers import SearchProviderType
+                        if not self.provider.private and self.provider.provider_type in [SearchProviderType.NZB, SearchProviderType.TORRENT]:
+                            try:
+                                sickrage.app.api.provider.add_search_result(provider=self.providerID, data=dbData)
+                            except Exception as e:
+                                pass
         except (InvalidShowException, InvalidNameException):
             pass
 
-    def search_cache(self, show_id, season, episode, manualSearch=False, downCurQuality=False):
+    def search_cache(self, series_id, series_provider_id, season, episode, manualSearch=False, downCurQuality=False):
         cache_results = {}
         dbData = []
 
         # get data from external database
-        if sickrage.app.config.enable_api_providers_cache and not self.provider.private:
-            try:
-                dbData += sickrage.app.api.provider_cache.get(self.providerID, show_id, season, episode)['data']
-            except Exception:
-                pass
+        if sickrage.app.config.general.enable_sickrage_api and not self.provider.private:
+            resp = sickrage.app.api.provider.get_search_result(self.providerID, series_id, season, episode)
+            if resp and 'data' in resp:
+                dbData += resp['data']
 
         # get data from internal database
         session = sickrage.app.cache_db.session()
-        dbData += [x.as_dict() for x in session.query(CacheDB.Provider).filter_by(provider=self.providerID, series_id=show_id, season=season).filter(
-            CacheDB.Provider.episodes.contains("|{}|".format(episode)))]
+        dbData += [x.as_dict() for x in
+                   session.query(CacheDB.Provider).filter_by(provider=self.providerID,
+                                                             series_id=series_id,
+                                                             season=season).filter(CacheDB.Provider.episodes.contains("|{}|".format(episode)))]
 
         for curResult in dbData:
-            show_object = find_show(int(curResult["series_id"]))
-            if not show_object:
-                continue
-
             result = self.provider.get_result()
 
-            # ignore invalid and private IP address urls
-            if not validate_url(curResult["url"]):
-                if not curResult["url"].startswith('magnet'):
-                    continue
-            elif is_ip_private(curResult["url"].split(r'//')[-1].split(r'/')[0]):
+            result.series_id = int(curResult["series_id"])
+            result.series_provider_id = curResult["series_provider_id"]
+
+            # convert to series provider id enum
+            if not isinstance(result.series_provider_id, SeriesProviderID):
+                result.series_provider_id = SeriesProviderID[curResult["series_provider_id"]]
+
+            # get series, if it's not one of our shows then ignore it
+            series = find_show(result.series_id, result.series_provider_id)
+            if not series or series.series_provider_id != series_provider_id:
                 continue
 
             # ignored/required words, and non-tv junk
             if not show_names.filter_bad_releases(curResult["name"]):
                 continue
 
-            # get the show object, or if it's not one of our shows then ignore it
-            result.show_id = int(curResult["series_id"])
-
             # skip if provider is anime only and show is not anime
-            if self.provider.anime_only and not show_object.is_anime:
-                sickrage.app.log.debug("" + str(show_object.name) + " is not an anime, skiping")
+            if self.provider.anime_only and not series.is_anime:
+                sickrage.app.log.debug("" + str(series.name) + " is not an anime, skiping")
                 continue
 
             # get season and ep data (ignoring multi-eps for now)
@@ -312,25 +312,25 @@ class TVCache(object):
             result.season = curSeason
             result.episodes = [int(curEp) for curEp in filter(None, curResult["episodes"].split("|"))]
 
-            result.quality = int(curResult["quality"])
+            result.quality = Qualities(curResult["quality"])
             result.release_group = curResult["release_group"]
             result.version = curResult["version"]
 
             # make sure we want the episode
             wantEp = False
             for result_episode in result.episodes:
-                if show_object.want_episode(result.season, result_episode, result.quality, manualSearch, downCurQuality):
+                if series.want_episode(result.season, result_episode, result.quality, manualSearch, downCurQuality):
                     wantEp = True
 
             if not wantEp:
-                sickrage.app.log.info("Skipping " + curResult["name"] + " because we don't want an episode that's " + Quality.qualityStrings[result.quality])
+                sickrage.app.log.info("Skipping " + curResult["name"] + " because we don't want an episode that's " + result.quality.display_name)
                 continue
 
             # build a result object
             result.name = curResult["name"]
             result.url = curResult["url"]
 
-            sickrage.app.log.info("Found cached {} result {}".format(result.type, result.name))
+            sickrage.app.log.info("Found cached {} result {}".format(result.provider_type, result.name))
 
             result.seeders = curResult.get("seeders", -1)
             result.leechers = curResult.get("leechers", -1)
