@@ -18,23 +18,20 @@
 #  You should have received a copy of the GNU General Public License
 #  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 # ##############################################################################
-import locale
 import logging
 import os
 import pkgutil
-import platform
 import re
 import sys
 from logging import FileHandler, CRITICAL, DEBUG, ERROR, INFO, WARNING
 from logging.handlers import RotatingFileHandler
 
-import raven
-from raven.handlers.logging import SentryHandler
 from unidecode import unidecode
 
 import sickrage
-from sickrage.core import make_dir
 from sickrage.core.classes import ErrorViewer, WarningViewer
+from sickrage.core.helpers import make_dir
+from sickrage.search_providers import SearchProviderType
 
 
 class Logger(logging.getLoggerClass()):
@@ -60,8 +57,6 @@ class Logger(logging.getLoggerClass()):
         self.INFO = INFO
         self.DB = 5
 
-        self.CENSORED_ITEMS = {}
-
         self.logLevels = {
             'CRITICAL': self.CRITICAL,
             'ERROR': self.ERROR,
@@ -75,6 +70,7 @@ class Logger(logging.getLoggerClass()):
         self.loggers = {'sickrage': self,
                         'tornado.general': logging.getLogger('tornado.general'),
                         'tornado.application': logging.getLogger('tornado.application'),
+                        'apscheduler.executors': logging.getLogger('apscheduler.executors'),
                         'apscheduler.jobstores': logging.getLogger('apscheduler.jobstores'),
                         'apscheduler.scheduler': logging.getLogger('apscheduler.scheduler')}
 
@@ -89,42 +85,65 @@ class Logger(logging.getLoggerClass()):
         # start logger
         self.start()
 
+    @property
+    def censored_items(self):
+        try:
+            items = [
+                sickrage.app.config.user.password,
+                sickrage.app.config.sabnzbd.password,
+                sickrage.app.config.sabnzbd.apikey,
+                sickrage.app.config.nzbget.password,
+                sickrage.app.config.synology.password,
+                sickrage.app.config.torrent.password,
+                sickrage.app.config.kodi.password,
+                sickrage.app.config.plex.password,
+                sickrage.app.config.plex.server_token,
+                sickrage.app.config.emby.apikey,
+                sickrage.app.config.growl.password,
+                sickrage.app.config.freemobile.apikey,
+                sickrage.app.config.telegram.apikey,
+                sickrage.app.config.join_app.apikey,
+                sickrage.app.config.prowl.apikey,
+                sickrage.app.config.twitter.password,
+                sickrage.app.config.twilio.auth_token,
+                sickrage.app.config.boxcar2.access_token,
+                sickrage.app.config.pushover.apikey,
+                sickrage.app.config.nma.api_keys,
+                sickrage.app.config.pushalot.auth_token,
+                sickrage.app.config.pushbullet.api_key,
+                sickrage.app.config.email.password,
+                sickrage.app.config.subtitles.addic7ed_pass,
+                sickrage.app.config.subtitles.legendastv_pass,
+                sickrage.app.config.subtitles.itasa_pass,
+                sickrage.app.config.subtitles.opensubtitles_pass,
+                sickrage.app.config.anidb.password
+            ]
+
+            for __, search_provider in sickrage.app.search_providers.all().items():
+                if search_provider.provider_type in [SearchProviderType.NZB, SearchProviderType.NEWZNAB]:
+                    items.append(search_provider.api_key)
+                elif search_provider.provider_type == SearchProviderType.TORRENT_RSS and not search_provider.default:
+                    items.append(search_provider.urls['base_url'])
+
+                items.append(search_provider.cookies)
+
+                [items.append(search_provider.custom_settings[item]) for item in [
+                    'digest',
+                    'hash',
+                    'api_key',
+                    'password',
+                    'passkey',
+                    'pin',
+                ] if item in search_provider.custom_settings]
+
+            return list(filter(None, items))
+        except AttributeError:
+            return []
+
     def start(self):
         # remove all handlers
         self.handlers.clear()
 
-        sentry_ignore_exceptions = [
-            'KeyboardInterrupt',
-            'PermissionError',
-            'FileNotFoundError',
-            'EpisodeNotFoundException'
-        ]
-
-        # sentry log handler
-        sentry_client = raven.Client(
-            'https://d4bf4ed225c946c8972c7238ad07d124@sentry.sickrage.ca/2?verify_ssl=0',
-            release=sickrage.version(),
-            repos={'sickrage': {'name': 'sickrage/sickrage'}},
-            ignore_exceptions=sentry_ignore_exceptions
-        )
-
-        sentry_tags = {
-            'platform': platform.platform(),
-            'locale': locale.getdefaultlocale(),
-            'python': platform.python_version()
-        }
-
-        if sickrage.app.config and sickrage.app.config.sub_id:
-            sentry_tags.update({'sub_id': sickrage.app.config.sub_id})
-        if sickrage.app.config and sickrage.app.config.app_id:
-            sentry_tags.update({'app_id': sickrage.app.config.app_id})
-
-        sentry_handler = SentryHandler(client=sentry_client, ignore_exceptions=sentry_ignore_exceptions, tags=sentry_tags)
-
-        sentry_handler.setLevel(self.logLevels['ERROR'])
-        sentry_handler.set_name('sentry')
-        self.addHandler(sentry_handler)
-
         # console log handler
         if self.consoleLogging:
             console_handler = logging.StreamHandler()
@@ -169,17 +188,14 @@ class Logger(logging.getLoggerClass()):
             self.addHandler(rfh_errors)
 
     def makeRecord(self, name, level, fn, lno, msg, args, exc_info, func=None, extra=None, sinfo=None):
-        if (False, True)[name in self.loggers]:
+        if name in self.loggers:
             record = super(Logger, self).makeRecord(name, level, fn, lno, msg, args, exc_info, func, extra, sinfo)
 
             try:
-                record.msg = re.sub(
-                    r"(.*)\b({})\b(.*)".format(
-                        '|'.join([x for x in self.CENSORED_ITEMS.values() if len(x)])), r"\1\3",
-                    record.msg)
+                def repl(m):
+                    return '*' * len(m.group())
 
-                # needed because Newznab apikey isn't stored as key=value in a section.
-                record.msg = re.sub(r"([&?]r|[&?]apikey|[&?]api_key)=[^&]*([&\w]?)", r"\1=**********\2", record.msg)
+                record.msg = re.sub(fr"\b({'|'.join(self.censored_items)})\b", repl, record.msg)
                 record.msg = unidecode(record.msg)
             except:
                 pass
@@ -191,7 +207,7 @@ class Logger(logging.getLoggerClass()):
             return record
 
     def set_level(self):
-        self.debugLogging = sickrage.app.config.debug
+        self.debugLogging = sickrage.app.debug
         level = DEBUG if self.debugLogging else INFO
         for __, logger in self.loggers.items():
             logger.setLevel(level)
@@ -238,7 +254,8 @@ class Logger(logging.getLoggerClass()):
         super(Logger, self).exception(msg, *args, **kwargs)
 
     def error(self, msg, *args, **kwargs):
-        super(Logger, self).error(msg, exc_info=1, *args, **kwargs)
+        kwargs['exc_info'] = True
+        super(Logger, self).error(msg, *args, **kwargs)
 
     def warning(self, msg, *args, **kwargs):
         super(Logger, self).warning(msg, *args, **kwargs)
