@@ -1,22 +1,24 @@
-# Author: echel0n <echel0n@sickrage.ca>
-# URL: https://sickrage.ca
-#
-# This file is part of SickRage.
-#
-# SickRage is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# SickRage is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with SickRage.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
+#  Author: echel0n <echel0n@sickrage.ca>
+#  URL: https://sickrage.ca/
+#  Git: https://git.sickrage.ca/SiCKRAGE/sickrage.git
+#  -
+#  This file is part of SiCKRAGE.
+#  -
+#  SiCKRAGE is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#  -
+#  SiCKRAGE is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#  -
+#  You should have received a copy of the GNU General Public License
+#  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
+# ##############################################################################
 
-from __future__ import unicode_literals
 
 import os
 import re
@@ -25,17 +27,17 @@ from collections import OrderedDict
 from threading import Lock
 
 from dateutil import parser
+from sqlalchemy import orm
 
 import sickrage
-from sickrage.core.common import Quality
-from sickrage.core.helpers import findCertainShow, full_sanitizeSceneName, remove_extension
+from sickrage.core.common import Quality, Qualities
+from sickrage.core.databases.main import MainDB
+from sickrage.core.enums import SeriesProviderID
+from sickrage.core.helpers import remove_extension, strip_accents
 from sickrage.core.nameparser import regexes
-from sickrage.core.scene_exceptions import get_scene_exception_by_name
-from sickrage.core.scene_numbering import get_absolute_number_from_season_and_episode, get_indexer_absolute_numbering, \
-    get_indexer_numbering
-from sickrage.core.traktapi import srTraktAPI
-from sickrage.indexers import IndexerApi
-from sickrage.indexers.exceptions import indexer_episodenotfound, indexer_error
+from sickrage.core.scene_numbering import get_absolute_number_from_season_and_episode, get_series_provider_absolute_numbering, get_series_provider_numbering
+from sickrage.core.tv.show.helpers import find_show_by_name, find_show, find_show_by_scene_exception
+from sickrage.series_providers.helpers import search_series_provider_for_series_id
 
 
 class NameParser(object):
@@ -43,67 +45,56 @@ class NameParser(object):
     NORMAL_REGEX = 1
     ANIME_REGEX = 2
 
-    def __init__(self, file_name=True, showObj=None, naming_pattern=False, validate_show=True):
+    def __init__(self, file_name=True, series_id=None, series_provider_id=None, naming_pattern=False, validate_show=True):
         self.file_name = file_name
-        self.showObj = showObj
+        self.show_obj = find_show(series_id, series_provider_id) if series_id and series_provider_id else None
         self.naming_pattern = naming_pattern
         self.validate_show = validate_show
 
-        if self.showObj and not self.showObj.is_anime:
+        if self.show_obj and not self.show_obj.is_anime:
             self._compile_regexes(self.NORMAL_REGEX)
-        elif self.showObj and self.showObj.is_anime:
+        elif self.show_obj and self.show_obj.is_anime:
             self._compile_regexes(self.ANIME_REGEX)
         else:
             self._compile_regexes(self.ALL_REGEX)
 
     def get_show(self, name):
-        show = None
-        show_id = None
+        if not name:
+            return None
 
-        if not all([name, sickrage.app.showlist]):
-            return show, show_id
+        def series_provider_lookup(term):
+            for _series_provider_id in SeriesProviderID:
+                result = search_series_provider_for_series_id(term, _series_provider_id)
+                if result:
+                    return result, _series_provider_id
+                return None, None
 
-        def cache_lookup(name):
-            return sickrage.app.name_cache.get(name)
+        def scene_exception_lookup(term):
+            tv_show = find_show_by_scene_exception(term)
+            if tv_show:
+                return tv_show.series_id, tv_show.series_provider_id
+            return None, None
 
-        def scene_exception_lookup(name):
-            return get_scene_exception_by_name(name)[0]
+        def show_cache_lookup(term):
+            tv_show = find_show_by_name(term)
+            if tv_show:
+                return tv_show.series_id, tv_show.series_provider_id
+            return None, None
 
-        def indexer_lookup(name):
-            show_id1 = int(IndexerApi().searchForShowID(full_sanitizeSceneName(name))[2])
-            show_id2 = int(srTraktAPI()['search'].query(full_sanitizeSceneName(name), 'show')[0].ids['tvdb'])
-            return (None, show_id1)[show_id1 == show_id2]
+        for lookup in [show_cache_lookup, scene_exception_lookup, series_provider_lookup]:
+            for show_name in list({name, strip_accents(name), strip_accents(name).replace("'", " ")}):
+                try:
+                    series_id, series_provider_id = lookup(show_name)
+                    if not series_id or not series_provider_id:
+                        continue
 
-        lookup_list = [
-            lambda: cache_lookup(name),
-            lambda: scene_exception_lookup(name),
-            lambda: indexer_lookup(name),
-        ]
+                    if self.validate_show and not find_show(series_id, series_provider_id):
+                        continue
 
-        # lookup show id
-        for lookup in lookup_list:
-            if show or show_id is not None:
-                continue
-
-            try:
-                show_id = int(lookup())
-                if show_id == 0:
-                    continue
-
-                sickrage.app.name_cache.put(name, show_id)
-                if self.validate_show:
-                    show = findCertainShow(show_id)
-                else:
-                    from sickrage.core.tv.show import TVShow
-                    show = TVShow(1, show_id)
-            except Exception:
-                pass
-
-        if show_id is None:
-            # ignore show name by caching it with a indexerid of 0
-            sickrage.app.name_cache.put(name, 0)
-
-        return show, show_id or 0
+                    if series_id and series_provider_id:
+                        return series_id, series_provider_id
+                except Exception as e:
+                    sickrage.app.log.debug('SiCKRAGE encountered a error when attempting to lookup a series id by show name, Error: {!r}'.format(e))
 
     @staticmethod
     def clean_series_name(series_name):
@@ -150,8 +141,10 @@ class NameParser(object):
         if not name:
             return
 
+        session = sickrage.app.main_db.session()
+
         matches = []
-        bestResult = None
+        best_result = None
 
         for (cur_regex_num, cur_regex_name, cur_regex) in self.compiled_regexes:
             match = cur_regex.match(name)
@@ -169,10 +162,6 @@ class NameParser(object):
                 result.series_name = match.group('series_name')
                 if result.series_name:
                     result.series_name = self.clean_series_name(result.series_name)
-                    result.score += 1
-
-            if 'series_num' in named_groups and match.group('series_num'):
-                result.score += 1
 
             if 'season_num' in named_groups:
                 tmp_season = int(match.group('season_num'))
@@ -182,29 +171,23 @@ class NameParser(object):
                     continue
 
                 result.season_number = tmp_season
-                result.score += 1
 
             if 'ep_num' in named_groups:
                 ep_num = self._convert_number(match.group('ep_num'))
                 if 'extra_ep_num' in named_groups and match.group('extra_ep_num'):
-                    tmp_episodes = range(ep_num, self._convert_number(match.group('extra_ep_num')) + 1)
-                    if len(tmp_episodes) > 6:
-                        continue
-                    result.score += 1
+                    tmp_episodes = list(range(ep_num, self._convert_number(match.group('extra_ep_num')) + 1))
+                    # if len(tmp_episodes) > 6:
+                    #     continue
                 else:
                     tmp_episodes = [ep_num]
 
                 result.episode_numbers = tmp_episodes
-                result.score += 3
 
             if 'ep_ab_num' in named_groups:
                 ep_ab_num = self._convert_number(match.group('ep_ab_num'))
-                result.score += 1
 
                 if 'extra_ab_ep_num' in named_groups and match.group('extra_ab_ep_num'):
-                    result.ab_episode_numbers = range(ep_ab_num,
-                                                      self._convert_number(match.group('extra_ab_ep_num')) + 1)
-                    result.score += 1
+                    result.ab_episode_numbers = list(range(ep_ab_num, self._convert_number(match.group('extra_ab_ep_num')) + 1))
                 else:
                     result.ab_episode_numbers = [ep_ab_num]
 
@@ -212,7 +195,7 @@ class NameParser(object):
                 air_date = match.group('air_date')
                 try:
                     result.air_date = parser.parse(air_date, fuzzy=True).date()
-                    result.score += 1
+                    result.score += cur_regex_num
                 except Exception:
                     continue
 
@@ -224,11 +207,9 @@ class NameParser(object):
                         r'([. _-]|^)(special|extra)s?\w*([. _-]|$)', tmp_extra_info, re.I):
                     continue
                 result.extra_info = tmp_extra_info
-                result.score += 1
 
             if 'release_group' in named_groups:
                 result.release_group = match.group('release_group')
-                result.score += 1
 
             if 'version' in named_groups:
                 # assigns version to anime file if detected using anime regex. Non-anime regex receives -1
@@ -240,131 +221,123 @@ class NameParser(object):
             else:
                 result.version = -1
 
+            result.score += len([x for x in result.__dict__ if getattr(result, x, None) is not None])
             matches.append(result)
 
         if len(matches):
             # pick best match with highest score based on placement
-            bestResult = max(sorted(matches, reverse=True, key=lambda x: x.which_regex), key=lambda x: x.score)
+            best_result = max(sorted(matches, reverse=True, key=lambda x: x.which_regex), key=lambda x: x.score)
 
-            bestResult.show = self.showObj
-            bestResult.indexerid = self.showObj.indexerid if self.showObj else 0
+            show_obj = None
+            best_result.series_id = self.show_obj.series_id if self.show_obj else 0
+            best_result.series_provider_id = self.show_obj.series_provider_id if self.show_obj else SeriesProviderID.THETVDB
 
             if not self.naming_pattern:
                 # try and create a show object for this result
-                bestResult.show, bestResult.indexerid = self.get_show(bestResult.series_name)
+                result = self.get_show(best_result.series_name)
+                if result and len(result) == 2:
+                    best_result.series_id, best_result.series_provider_id = result
 
-                # confirm passed in show object indexer id matches result show object indexer id
-                if self.showObj and bestResult.show:
-                    if self.showObj.indexerid == bestResult.show.indexerid:
-                        bestResult.show = self.showObj
-                    else:
-                        bestResult.show = None
-                        bestResult.indexerid = 0
+                if best_result.series_id and best_result.series_provider_id:
+                    show_obj = find_show(best_result.series_id, best_result.series_provider_id)
 
             # if this is a naming pattern test or result doesn't have a show object then return best result
-            if not bestResult.show or self.naming_pattern:
-                return bestResult
+            if not show_obj or self.naming_pattern:
+                return best_result
 
             # get quality
-            bestResult.quality = Quality.nameQuality(name, bestResult.show.is_anime)
+            best_result.quality = Quality.name_quality(name, show_obj.is_anime)
 
             new_episode_numbers = []
             new_season_numbers = []
             new_absolute_numbers = []
 
             # if we have an air-by-date show then get the real season/episode numbers
-            if bestResult.is_air_by_date:
-                airdate = bestResult.air_date.toordinal()
-
-                dbData = [x for x in sickrage.app.main_db.get_many('tv_episodes', bestResult.show.indexerid)
-                          if x['indexer'] == bestResult.show.indexer and x['airdate'] == airdate]
-
-                season_number = None
-                episode_numbers = []
-
-                if dbData:
-                    season_number = int(dbData[0]['season'])
-                    episode_numbers = [int(dbData[0]['episode'])]
+            if best_result.is_air_by_date:
+                try:
+                    dbData = session.query(MainDB.TVEpisode).filter_by(series_id=show_obj.series_id, series_provider_id=show_obj.series_provider_id,
+                                                                       airdate=best_result.air_date).one()
+                    season_number = int(dbData.season)
+                    episode_numbers = [int(dbData.episode)]
+                except (orm.exc.NoResultFound, orm.exc.MultipleResultsFound):
+                    season_number = None
+                    episode_numbers = []
 
                 if not season_number or not episode_numbers:
-                    try:
-                        lINDEXER_API_PARMS = IndexerApi(bestResult.show.indexer).api_params.copy()
-
-                        lINDEXER_API_PARMS[
-                            'language'] = bestResult.show.lang or sickrage.app.config.indexer_default_language
-
-                        t = IndexerApi(bestResult.show.indexer).indexer(**lINDEXER_API_PARMS)
-
-                        epObj = t[bestResult.show.indexerid].airedOn(bestResult.air_date)[0]
-
-                        season_number = int(epObj["airedseason"])
-                        episode_numbers = [int(epObj["airedepisodenumber"])]
-                    except indexer_episodenotfound:
-                        sickrage.app.log.warning("Unable to find episode with date {air_date} for show {show_name}, "
-                                                 "skipping".format(air_date=bestResult.air_date,
-                                                                   show_name=bestResult.show.name))
-                        episode_numbers = []
-                    except indexer_error as e:
-                        sickrage.app.log.warning(
-                            "Unable to contact " + IndexerApi(bestResult.show.indexer).name + ": {}".format(
-                                e))
-                        episode_numbers = []
+                    series_provider_language = show_obj.lang or sickrage.app.config.general.series_provider_default_language
+                    series = show_obj.series_provider.search(show_obj.series_id, language=series_provider_language)
+                    if series:
+                        ep_obj = series.aired_on(best_result.air_date)
+                        if not ep_obj:
+                            if best_result.in_showlist:
+                                sickrage.app.log.warning(f"Unable to find episode with date {best_result.air_date} for show {show_obj.name}, skipping")
+                            episode_numbers = []
+                        else:
+                            season_number = int(ep_obj[0]["airedseason"])
+                            episode_numbers = [int(ep_obj[0]["airedepisodenumber"])]
 
                 for epNo in episode_numbers:
                     s = season_number
                     e = epNo
 
-                    if bestResult.show.is_scene and not skip_scene_detection:
-                        (s, e) = get_indexer_numbering(bestResult.show.indexerid,
-                                                       bestResult.show.indexer,
-                                                       season_number,
-                                                       epNo)
-                    new_episode_numbers.append(e)
-                    new_season_numbers.append(s)
+                    if show_obj.scene and not skip_scene_detection:
+                        (s, e) = get_series_provider_numbering(show_obj.series_id,
+                                                               show_obj.series_provider_id,
+                                                               season_number,
+                                                               epNo)
+                    if s != -1:
+                        new_season_numbers.append(s)
 
-            elif bestResult.show.is_anime and bestResult.ab_episode_numbers:
-                scene_season = get_scene_exception_by_name(bestResult.series_name)[1]
-                for epAbsNo in bestResult.ab_episode_numbers:
+                    if e != -1:
+                        new_episode_numbers.append(e)
+
+            elif show_obj.is_anime and best_result.ab_episode_numbers:
+                for epAbsNo in best_result.ab_episode_numbers:
                     a = epAbsNo
 
-                    if bestResult.show.is_scene:
-                        a = get_indexer_absolute_numbering(bestResult.show.indexerid,
-                                                           bestResult.show.indexer, epAbsNo,
-                                                           True, scene_season)
+                    if show_obj.scene:
+                        scene_result = show_obj.get_scene_exception_by_name(best_result.series_name)
+                        if scene_result:
+                            a = get_series_provider_absolute_numbering(show_obj.series_id,
+                                                                       show_obj.series_provider_id, epAbsNo,
+                                                                       True, scene_result[1])
 
-                    (s, e) = bestResult.show.get_all_episodes_from_absolute_number([a])
+                    (s, e) = show_obj.get_all_episodes_from_absolute_number([a])
+
+                    if a != -1:
+                        new_absolute_numbers.append(a)
 
-                    new_absolute_numbers.append(a)
-                    new_episode_numbers.extend(e)
                     new_season_numbers.append(s)
+                    new_episode_numbers.extend(e)
 
-            elif bestResult.season_number and bestResult.episode_numbers:
-                for epNo in bestResult.episode_numbers:
-                    s = bestResult.season_number
+            elif best_result.season_number and best_result.episode_numbers:
+                for epNo in best_result.episode_numbers:
+                    s = best_result.season_number
                     e = epNo
 
-                    if bestResult.show.is_scene and not skip_scene_detection:
-                        (s, e) = get_indexer_numbering(bestResult.show.indexerid,
-                                                       bestResult.show.indexer,
-                                                       bestResult.season_number,
-                                                       epNo)
-                    if bestResult.show.is_anime:
-                        a = get_absolute_number_from_season_and_episode(bestResult.show, s, e)
-                        if a:
+                    if show_obj.scene and not skip_scene_detection:
+                        (s, e) = get_series_provider_numbering(show_obj.series_id,
+                                                               show_obj.series_provider_id,
+                                                               best_result.season_number,
+                                                               epNo)
+                    if show_obj.is_anime:
+                        a = get_absolute_number_from_season_and_episode(show_obj.series_id, show_obj.series_provider_id, s, e)
+                        if a not in [-1, None]:
                             new_absolute_numbers.append(a)
 
-                    new_episode_numbers.append(e)
-                    new_season_numbers.append(s)
+                    if s != -1:
+                        new_season_numbers.append(s)
 
-            # need to do a quick sanity check heregex.  It's possible that we now have episodes
+                    if e != -1:
+                        new_episode_numbers.append(e)
+
+            # need to do a quick sanity check here.  It's possible that we now have episodes
             # from more than one season (by tvdb numbering), and this is just too much
             # for sickrage, so we'd need to flag it.
             new_season_numbers = list(set(new_season_numbers))  # remove duplicates
             if len(new_season_numbers) > 1:
-                raise InvalidNameException("Scene numbering results episodes from "
-                                           "seasons %s, (i.e. more than one) and "
-                                           "sickrage does not support this.  "
-                                           "Sorry." % new_season_numbers)
+                raise InvalidNameException(
+                    f"Scene numbering results episodes from seasons {new_season_numbers}, (i.e. more than one) and sickrage does not support this.  Sorry.")
 
             # I guess it's possible that we'd have duplicate episodes too, so lets
             # eliminate them
@@ -376,20 +349,19 @@ class NameParser(object):
             new_absolute_numbers.sort()
 
             if len(new_absolute_numbers):
-                bestResult.ab_episode_numbers = new_absolute_numbers
+                best_result.ab_episode_numbers = new_absolute_numbers
 
             if len(new_season_numbers) and len(new_episode_numbers):
-                bestResult.episode_numbers = new_episode_numbers
-                bestResult.season_number = new_season_numbers[0]
+                best_result.episode_numbers = new_episode_numbers
+                best_result.season_number = new_season_numbers[0]
 
-            if bestResult.show.is_scene and not skip_scene_detection:
-                sickrage.app.log.debug(
-                    "Converted parsed result {} into {}".format(bestResult.original_name, bestResult))
+            if show_obj.scene and not skip_scene_detection:
+                sickrage.app.log.debug(f"Scene converted parsed result {best_result.original_name} into {best_result}")
 
         # CPU sleep
         time.sleep(0.02)
 
-        return bestResult
+        return best_result
 
     def _combine_results(self, first, second, attr):
         # if the first doesn't exist then return the second or nothing
@@ -502,20 +474,19 @@ class NameParser(object):
             if dir_name_result:
                 final_result.which_regex |= dir_name_result.which_regex
 
-        final_result.show = self._combine_results(file_name_result, dir_name_result, 'show')
-        final_result.indexerid = self._combine_results(file_name_result, dir_name_result, 'indexerid')
+        final_result.series_id = self._combine_results(file_name_result, dir_name_result, 'series_id')
+        final_result.series_provider_id = self._combine_results(file_name_result, dir_name_result, 'series_provider_id')
         final_result.quality = self._combine_results(file_name_result, dir_name_result, 'quality')
 
-        if self.validate_show and not self.naming_pattern and not final_result.show:
-            raise InvalidShowException("Unable to match {} to a show in your database. Parser result: {}".format(
-                name, final_result))
+        if self.validate_show:
+            if not self.naming_pattern and (not final_result.series_id or not final_result.series_provider_id):
+                raise InvalidShowException("Unable to match {} to a show in your database. Parser result: {}".format(name, final_result))
 
         # if there's no useful info in it then raise an exception
         if final_result.season_number is None and not final_result.episode_numbers and final_result.air_date is None and not final_result.ab_episode_numbers and not final_result.series_name:
-            raise InvalidNameException("Unable to parse {} to a valid episode of {}. Parser result: {}".format(
-                name, final_result.show.name, final_result))
+            raise InvalidNameException("Unable to parse {} to a valid episode. Parser result: {}".format(name, final_result))
 
-        if cache_result and final_result.show:
+        if cache_result and final_result.series_id and final_result.series_provider_id:
             name_parser_cache.add(name, final_result)
 
         sickrage.app.log.debug("Parsed {} into {}".format(name, final_result))
@@ -532,8 +503,8 @@ class ParseResult(object):
                  release_group=None,
                  air_date=None,
                  ab_episode_numbers=None,
-                 show=None,
-                 indexerid=None,
+                 series_id=None,
+                 series_provider_id=None,
                  score=None,
                  quality=None,
                  version=None
@@ -544,18 +515,19 @@ class ParseResult(object):
         self.season_number = season_number
         self.episode_numbers = episode_numbers or []
         self.ab_episode_numbers = ab_episode_numbers or []
-        self.quality = quality or Quality.UNKNOWN
+        self.quality = quality or Qualities.UNKNOWN
         self.extra_info = extra_info
         self.release_group = release_group
         self.air_date = air_date
-        self.show = show
-        self.indexerid = indexerid or 0
+        self.series_id = series_id or 0
+        self.series_provider_id = series_provider_id or SeriesProviderID.THETVDB
         self.score = score
         self.version = version
         self.which_regex = set()
 
     def __eq__(self, other):
         return other and all([
+            self.__class__ == other.__class__,
             self.series_name == other.series_name,
             self.season_number == other.season_number,
             self.episode_numbers == other.episode_numbers,
@@ -563,25 +535,23 @@ class ParseResult(object):
             self.release_group == other.release_group,
             self.air_date == other.air_date,
             self.ab_episode_numbers == other.ab_episode_numbers,
-            self.show == other.show,
             self.score == other.score,
             self.quality == other.quality,
             self.version == other.version
         ])
 
-    def __unicode__(self):
+    def __str__(self):
         to_return = ""
         if self.series_name is not None:
             to_return += 'SHOW:[{}]'.format(self.series_name)
         if self.season_number is not None:
             to_return += ' SEASON:[{}]'.format(str(self.season_number).zfill(2))
         if self.episode_numbers and len(self.episode_numbers):
-            for ep_num in self.episode_numbers:
-                to_return += ' EPISODE:[{}]'.format(str(ep_num).zfill(2))
+            to_return += ' EPISODE:[{}]'.format(','.join(str(x).zfill(2) for x in self.episode_numbers))
         if self.is_air_by_date:
             to_return += ' AIRDATE:[{}]'.format(self.air_date)
         if self.ab_episode_numbers:
-            to_return += ' ABS:[{}]'.format(self.ab_episode_numbers)
+            to_return += ' ABS:[{}]'.format(','.join(str(x).zfill(3) for x in self.ab_episode_numbers))
         if self.version and self.is_anime is True:
             to_return += ' ANIME VER:[{}]'.format(self.version)
         if self.release_group:
@@ -593,9 +563,6 @@ class ParseResult(object):
 
         return to_return
 
-    def __str__(self):
-        return self.__unicode__().encode('utf-8', errors='replace')
-
     @property
     def is_air_by_date(self):
         if self.air_date:
@@ -608,6 +575,12 @@ class ParseResult(object):
             return True
         return False
 
+    @property
+    def in_showlist(self):
+        if find_show(self.series_id, self.series_provider_id):
+            return True
+        return False
+
 
 class NameParserCache(object):
     def __init__(self):
