@@ -24,8 +24,8 @@ import datetime
 import threading
 
 import sickrage
-from sickrage.core.common import Quality, DOWNLOADED, SNATCHED, SNATCHED_PROPER, WANTED
-from sickrage.core.queues.search import BacklogQueueItem
+from sickrage.core.common import Quality, Qualities, EpisodeStatus
+from sickrage.core.queues.search import BacklogSearchTask
 from sickrage.core.tv.show.helpers import find_show, get_show_list
 
 
@@ -34,47 +34,44 @@ class BacklogSearcher(object):
         self.name = "BACKLOG"
         self.lock = threading.Lock()
         self.cycleTime = 21 / 60 / 24
-        self.amActive = False
+        self.running = False
         self.amPaused = False
         self.amWaiting = False
         self.forced = False
 
-    def run(self, force=False):
-        if self.amActive and not force:
+    def task(self, force=False):
+        if self.running and not force:
             return
 
-        # set thread name
-        threading.currentThread().setName(self.name)
-
-        # set cycle time
-        self.cycleTime = sickrage.app.config.backlog_searcher_freq / 60 / 24
-
         try:
+            self.running = True
+
+            # set thread name
+            threading.currentThread().setName(self.name)
+
+            # set cycle time
+            self.cycleTime = sickrage.app.config.general.backlog_searcher_freq / 60 / 24
+
             self.forced = force
+
             self.search_backlog()
         finally:
-            self.amActive = False
+            self.running = False
 
     def am_running(self):
-        sickrage.app.log.debug("amWaiting: " + str(self.amWaiting) + ", amActive: " + str(self.amActive))
-        return (not self.amWaiting) and self.amActive
+        sickrage.app.log.debug("amWaiting: " + str(self.amWaiting) + ", running: " + str(self.running))
+        return (not self.amWaiting) and self.running
 
-    def search_backlog(self, show_id=None):
-        if self.amActive:
-            sickrage.app.log.debug("Backlog is still running, not starting it again")
-            return
-
-        self.amActive = True
+    def search_backlog(self, series_id=None, series_provider_id=None):
         self.amPaused = False
 
-        show_list = [find_show(show_id)] if show_id else get_show_list()
+        show_list = [find_show(series_id, series_provider_id)] if series_id and series_provider_id else get_show_list()
 
-        cur_date = datetime.date.today()
         from_date = datetime.date.min
 
-        if not show_id and self.forced:
-            sickrage.app.log.info("Running limited backlog on missed episodes " + str(sickrage.app.config.backlog_days) + " day(s) old")
-            from_date = datetime.date.today() - datetime.timedelta(days=sickrage.app.config.backlog_days)
+        if not series_id and self.forced:
+            sickrage.app.log.info("Running limited backlog on missed episodes " + str(sickrage.app.config.general.backlog_days) + " day(s) old")
+            from_date = datetime.date.today() - datetime.timedelta(days=sickrage.app.config.general.backlog_days)
         else:
             sickrage.app.log.info('Running full backlog search on missed episodes for all shows')
 
@@ -90,17 +87,15 @@ class BacklogSearcher(object):
                 continue
 
             for season, episode in wanted:
-                if (curShow.indexer_id, season, episode) in sickrage.app.search_queue.SNATCH_HISTORY:
-                    sickrage.app.search_queue.SNATCH_HISTORY.remove((curShow.indexer_id, season, episode))
+                if (curShow.series_id, season, episode) in sickrage.app.search_queue.SNATCH_HISTORY:
+                    sickrage.app.search_queue.SNATCH_HISTORY.remove((curShow.series_id, season, episode))
 
-                sickrage.app.io_loop.add_callback(sickrage.app.search_queue.put, BacklogQueueItem(curShow.indexer_id, season, episode))
+                sickrage.app.search_queue.put(BacklogSearchTask(curShow.series_id, curShow.series_provider_id, season, episode))
 
-            if from_date == datetime.date.min and not show_id:
-                self._set_last_backlog_search(curShow, cur_date)
+            if from_date == datetime.date.min and not series_id:
+                self._set_last_backlog_search(curShow, datetime.datetime.now())
                 curShow.save()
 
-        self.amActive = False
-
     @staticmethod
     def _get_wanted(show, from_date):
         any_qualities, best_qualities = Quality.split_quality(show.quality)
@@ -113,26 +108,26 @@ class BacklogSearcher(object):
             if not episode_object.season > 0 or not datetime.date.today() > episode_object.airdate > from_date:
                 continue
 
-            cur_status, cur_quality = Quality.split_composite_status(int(episode_object.status or -1))
+            cur_status, cur_quality = Quality.split_composite_status(episode_object.status)
 
             # if we need a better one then say yes
-            if cur_status not in {WANTED, DOWNLOADED, SNATCHED, SNATCHED_PROPER}:
+            if cur_status not in {EpisodeStatus.WANTED, EpisodeStatus.DOWNLOADED, EpisodeStatus.SNATCHED, EpisodeStatus.SNATCHED_PROPER}:
                 continue
 
-            if cur_status != WANTED:
+            if cur_status != EpisodeStatus.WANTED:
                 if best_qualities:
                     if cur_quality in best_qualities:
                         continue
-                    elif cur_quality != Quality.UNKNOWN and cur_quality > max(best_qualities):
+                    elif cur_quality != Qualities.UNKNOWN and cur_quality > max(best_qualities):
                         continue
-                else:
+                elif any_qualities:
                     if cur_quality in any_qualities:
                         continue
-                    elif cur_quality != Quality.UNKNOWN and cur_quality > max(any_qualities):
+                    elif cur_quality != Qualities.UNKNOWN and cur_quality > max(any_qualities):
                         continue
 
             # skip upgrading quality of downloaded episodes if enabled
-            if cur_status == DOWNLOADED and show.skip_downloaded:
+            if cur_status == EpisodeStatus.DOWNLOADED and show.skip_downloaded:
                 continue
 
             wanted += [(episode_object.season, episode_object.episode)]
@@ -142,9 +137,9 @@ class BacklogSearcher(object):
     @staticmethod
     def _get_last_backlog_search(show):
         sickrage.app.log.debug("Retrieving the last check time from the DB")
-        return int(show.last_backlog_search)
+        return show.last_backlog_search
 
     @staticmethod
     def _set_last_backlog_search(show, when):
         sickrage.app.log.debug("Setting the last backlog in the DB to {}".format(when))
-        show.last_backlog_search = when.toordinal()
+        show.last_backlog_search = when
