@@ -19,40 +19,37 @@
 #  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 # ##############################################################################
 import json
-from abc import ABC
 
 import sickrage
 from sickrage.core.webserver.handlers.base import BaseHandler
 from sickrage.libs.trakt.interfaces.base import authenticated
 
 
-class AnnouncementsHandler(BaseHandler, ABC):
+class AnnouncementsHandler(BaseHandler):
     @authenticated
-    async def get(self, *args, **kwargs):
-        return await self.render(
-            'announcements.mako',
-            announcements=sickrage.app.announcements.get_all(),
-            title=_('Announcements'),
-            header=_('Announcements'),
-            topmenu='announcements',
-            controller='root',
-            action='announcements'
-        )
+    def get(self, *args, **kwargs):
+        return self.render('announcements.mako',
+                           announcements=sickrage.app.announcements.get_all(),
+                           title=_('Announcements'),
+                           header=_('Announcements'),
+                           topmenu='announcements',
+                           controller='root',
+                           action='announcements')
 
 
-class MarkAnnouncementSeenHandler(BaseHandler, ABC):
+class MarkAnnouncementSeenHandler(BaseHandler):
     @authenticated
-    async def post(self, *args, **kwargs):
+    def post(self, *args, **kwargs):
         ahash = self.get_argument('ahash')
 
         announcement = sickrage.app.announcements.get(ahash)
         if announcement:
             announcement.seen = True
 
-        return self.write(json.dumps({'success': True}))
+        return json.dumps({'success': True})
 
 
-class AnnouncementCountHandler(BaseHandler, ABC):
+class AnnouncementCountHandler(BaseHandler):
     @authenticated
-    async def get(self, *args, **kwargs):
-        return self.write(json.dumps({'count': sickrage.app.announcements.count()}))
+    def get(self, *args, **kwargs):
+        return json.dumps({'count': sickrage.app.announcements.count()})
