@@ -20,7 +20,6 @@
 # ##############################################################################
 
 import os
-from abc import ABC
 
 from tornado.web import authenticated
 
@@ -28,7 +27,7 @@ import sickrage
 from sickrage.core.webserver.handlers.base import BaseHandler
 
 
-class ConfigHandler(BaseHandler, ABC):
+class ConfigWebHandler(BaseHandler):
     menu = [
         {'title': _('Help and Info'), 'path': '/config/', 'icon': 'fas fa-info'},
         {'title': _('General'), 'path': '/config/general/', 'icon': 'fas fa-cogs'},
@@ -43,19 +42,17 @@ class ConfigHandler(BaseHandler, ABC):
     ]
 
     @authenticated
-    async def get(self, *args, **kwargs):
-        return await self.render(
-            "/config/index.mako",
-            submenu=self.menu,
-            title=_('Configuration'),
-            header=_('Configuration'),
-            topmenu="config",
-            controller='config',
-            action='index'
-        )
+    def get(self, *args, **kwargs):
+        return self.render('config/index.mako',
+                           submenu=self.menu,
+                           title=_('Configuration'),
+                           header=_('Configuration'),
+                           topmenu="config",
+                           controller='config',
+                           action='index')
 
 
-class ConfigResetHandler(BaseHandler, ABC):
+class ConfigResetHandler(BaseHandler):
     @authenticated
     def get(self, *args, **kwargs):
         sickrage.app.config.load(defaults=True)
