@@ -18,18 +18,22 @@
 #  You should have received a copy of the GNU General Public License
 #  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 # ##############################################################################
-from abc import ABC
+
 
 import sickrage
 from sickrage.core.webserver.handlers.base import BaseHandler
 
 
-class LogoutHandler(BaseHandler, ABC):
+class LogoutHandler(BaseHandler):
     def get(self, *args, **kwargs):
-        logout_uri = sickrage.app.oidc_client.get_url('end_session_endpoint')
-        redirect_uri = "{}://{}{}/login".format(self.request.protocol, self.request.host, sickrage.app.config.web_root)
+        logout_uri = sickrage.app.auth_server.get_url('end_session_endpoint') if sickrage.app.config.general.sso_auth_enabled else ""
+        redirect_uri = f"{self.request.protocol}://{self.request.host}{sickrage.app.config.general.web_root}/login"
 
+        self.clear_cookie('_sr')
         self.clear_cookie('_sr_access_token')
         self.clear_cookie('_sr_refresh_token')
 
-        return super(BaseHandler, self).redirect('{}?redirect_uri={}'.format(logout_uri, redirect_uri))
+        if logout_uri:
+            return self.redirect(f'{logout_uri}?redirect_uri={redirect_uri}', add_web_root=False)
+        else:
+            return self.redirect(f'{redirect_uri}', add_web_root=False)
