@@ -18,70 +18,78 @@
 #  You should have received a copy of the GNU General Public License
 #  along with SiCKRAGE.  If not, see <http://www.gnu.org/licenses/>.
 # ##############################################################################
-from abc import ABC
+import datetime
 
+from tornado.ioloop import IOLoop
 from tornado.web import authenticated
 
 import sickrage
 from sickrage.core.webserver.handlers.base import BaseHandler
 
 
-class ManageQueuesHandler(BaseHandler, ABC):
+class ManageQueuesHandler(BaseHandler):
     @authenticated
-    async def get(self, *args, **kwargs):
-        return await self.render(
-            "/manage/queues.mako",
-            backlogSearchPaused=sickrage.app.search_queue.is_backlog_searcher_paused(),
-            dailySearchPaused=sickrage.app.search_queue.is_daily_searcher_paused(),
-            backlogSearchStatus=sickrage.app.search_queue.is_backlog_in_progress(),
-            dailySearchStatus=sickrage.app.search_queue.is_dailysearch_in_progress(),
-            findPropersStatus=sickrage.app.proper_searcher.amActive,
-            searchQueueLength=sickrage.app.search_queue.queue_length(),
-            postProcessorPaused=sickrage.app.postprocessor_queue.is_paused,
-            postProcessorRunning=sickrage.app.postprocessor_queue.is_in_progress,
-            postProcessorQueueLength=sickrage.app.postprocessor_queue.queue_length,
-            title=_('Manage Queues'),
-            header=_('Manage Queues'),
-            topmenu='manage',
-            controller='manage',
-            action='queues'
-        )
+    def get(self, *args, **kwargs):
+        return self.render('manage/queues.mako',
+                           backlogSearchPaused=sickrage.app.search_queue.is_backlog_searcher_paused(),
+                           dailySearchPaused=sickrage.app.search_queue.is_daily_searcher_paused(),
+                           backlogSearchStatus=sickrage.app.search_queue.is_backlog_in_progress(),
+                           dailySearchStatus=sickrage.app.search_queue.is_dailysearch_in_progress(),
+                           findPropersStatus=sickrage.app.proper_searcher.running,
+                           searchQueueLength=sickrage.app.search_queue.queue_length(),
+                           postProcessorPaused=sickrage.app.postprocessor_queue.is_paused,
+                           postProcessorRunning=sickrage.app.postprocessor_queue.is_busy,
+                           postProcessorQueueLength=sickrage.app.postprocessor_queue.queue_length,
+                           title=_('Manage Queues'),
+                           header=_('Manage Queues'),
+                           topmenu='manage',
+                           controller='manage',
+                           action='queues')
 
 
-class ForceBacklogSearchHandler(BaseHandler, ABC):
+class ForceBacklogSearchHandler(BaseHandler):
     @authenticated
     def get(self, *args, **kwargs):
         # force it to run the next time it looks
-        if sickrage.app.scheduler.get_job(sickrage.app.backlog_searcher.name).func(True):
-            sickrage.app.log.info("Backlog search forced")
-            sickrage.app.alerts.message(_('Backlog search started'))
+        sickrage.app.log.info("Backlog search forced")
+        sickrage.app.alerts.message(_('Backlog search started'))
+
+        job = sickrage.app.scheduler.get_job(sickrage.app.backlog_searcher.name)
+        if job:
+            job.modify(next_run_time=datetime.datetime.utcnow(), kwargs={'force': True})
 
         return self.redirect("/manage/manageQueues/")
 
 
-class ForceDailySearchHandler(BaseHandler, ABC):
+class ForceDailySearchHandler(BaseHandler):
     @authenticated
     def get(self, *args, **kwargs):
         # force it to run the next time it looks
-        if sickrage.app.scheduler.get_job(sickrage.app.daily_searcher.name).func(True):
-            sickrage.app.log.info("Daily search forced")
-            sickrage.app.alerts.message(_('Daily search started'))
+        sickrage.app.log.info("Daily search forced")
+        sickrage.app.alerts.message(_('Daily search started'))
 
-        self.redirect("/manage/manageQueues/")
-
-
-class ForceFindPropersHandler(BaseHandler, ABC):
-    @authenticated
-    def get(self, *args, **kwargs):
-        # force it to run the next time it looks
-        if sickrage.app.scheduler.get_job(sickrage.app.proper_searcher.name).func(True):
-            sickrage.app.log.info("Find propers search forced")
-            sickrage.app.alerts.message(_('Find propers search started'))
+        job = sickrage.app.scheduler.get_job(sickrage.app.daily_searcher.name)
+        if job:
+            job.modify(next_run_time=datetime.datetime.utcnow(), kwargs={'force': True})
 
         return self.redirect("/manage/manageQueues/")
 
 
-class PauseDailySearcherHandler(BaseHandler, ABC):
+class ForceFindPropersHandler(BaseHandler):
+    @authenticated
+    def get(self, *args, **kwargs):
+        # force it to run the next time it looks
+        sickrage.app.log.info("Find propers search forced")
+        sickrage.app.alerts.message(_('Find propers search started'))
+
+        job = sickrage.app.scheduler.get_job(sickrage.app.proper_searcher.name)
+        if job:
+            job.modify(next_run_time=datetime.datetime.utcnow(), kwargs={'force': True})
+
+        return self.redirect("/manage/manageQueues/")
+
+
+class PauseDailySearcherHandler(BaseHandler):
     @authenticated
     def get(self, *args, **kwargs):
         paused = self.get_argument('paused')
@@ -94,7 +102,7 @@ class PauseDailySearcherHandler(BaseHandler, ABC):
         return self.redirect("/manage/manageQueues/")
 
 
-class PauseBacklogSearcherHandler(BaseHandler, ABC):
+class PauseBacklogSearcherHandler(BaseHandler):
     @authenticated
     def get(self, *args, **kwargs):
         paused = self.get_argument('paused')
@@ -107,7 +115,7 @@ class PauseBacklogSearcherHandler(BaseHandler, ABC):
         return self.redirect("/manage/manageQueues/")
 
 
-class PausePostProcessorHandler(BaseHandler, ABC):
+class PausePostProcessorHandler(BaseHandler):
     @authenticated
     def get(self, *args, **kwargs):
         paused = self.get_argument('paused')
