@@ -1,30 +1,52 @@
 import json
 from queue import Queue
 
+from jose import JWTError, ExpiredSignatureError
 from tornado.websocket import WebSocketHandler
 
 import sickrage
 
-clients = set()
-message_queue = Queue()
+
+def check_web_socket_queue():
+    if not WebSocketUIHandler.message_queue.empty():
+        message = WebSocketUIHandler.message_queue.get()
+        WebSocketUIHandler.broadcast(message)
 
 
 class WebSocketUIHandler(WebSocketHandler):
     """WebSocket handler to send and receive data to and from a web client."""
 
+    clients = set()
+    message_queue = Queue()
+
     def check_origin(self, origin):
         """Allow alternate origins."""
         return True
 
     def open(self, *args, **kwargs):
         """Client connected to the WebSocket."""
-        clients.add(self)
-        while not message_queue.empty():
-            self.write_message(message_queue.get())
+        WebSocketUIHandler.clients.add(self)
 
     def on_message(self, message):
         """Received a message from the client."""
-        sickrage.app.log.debug('WebSocket received message from {}: {}'.format(self.request.remote_ip, message))
+        json_message = json.loads(message)
+        if json_message.get('initial', False):
+            certs = sickrage.app.auth_server.certs()
+            auth_token = json_message['token']
+
+            try:
+                decoded_token = sickrage.app.auth_server.decode_token(auth_token, certs)
+                if sickrage.app.config.user.sub_id != decoded_token.get('sub'):
+                    WebSocketUIHandler.clients.remove(self)
+                    self.close(401, 'Not Authorized')
+            except ExpiredSignatureError:
+                WebSocketUIHandler.clients.remove(self)
+                self.close(401, 'Token expired')
+            except JWTError as e:
+                WebSocketUIHandler.clients.remove(self)
+                self.close(401, f'Improper JWT token supplied, {e!r}')
+        else:
+            sickrage.app.log.debug('WebSocket received message from {}: {}'.format(self.request.remote_ip, message))
 
     def data_received(self, chunk):
         """Received a streamed data chunk from the client."""
@@ -32,7 +54,12 @@ class WebSocketUIHandler(WebSocketHandler):
 
     def on_close(self):
         """Client disconnected from the WebSocket."""
-        clients.remove(self)
+        WebSocketUIHandler.clients.remove(self)
+
+    @classmethod
+    def broadcast(cls, msg):
+        for client in cls.clients:
+            client.write_message(msg)
 
     def __repr__(self):
         """Client representation."""
@@ -65,6 +92,4 @@ class WebSocketMessage(object):
 
     def push(self):
         """Push the message to all connected WebSocket clients."""
-        message_queue.put(self.json())
-        for client in clients:
-            sickrage.app.io_loop.add_callback(client.write_message, message_queue.get())
+        WebSocketUIHandler.message_queue.put(self.json())
